@@ -17,7 +17,7 @@ if not hasattr(JSONEncoder, "original_default"):
     # 
     # add patch for __json__
     # 
-    def wrapped_default(self, obj):
+    def wrapped_encoder(self, obj, *args, **kwargs):
         # 
         # first check the override_table
         # 
@@ -33,7 +33,9 @@ if not hasattr(JSONEncoder, "original_default"):
         # then check the __json__ method
         # 
         if hasattr(obj.__class__, "__json__"):
-            getattr(obj.__class__, "__json__", wrapped_default.default)(obj)
+            json_method = getattr(obj.__class__, "__json__")
+            if callable(json_method):
+                return json_method(obj)
         
         # 
         # then check the fallback_table
@@ -45,11 +47,14 @@ if not hasattr(JSONEncoder, "original_default"):
                 custom_converter_function = json.fallback_table[each_checker]
                 output = custom_converter_function(obj)
                 return output
-        return getattr(obj.__class__, "__json__", wrapped_default.default)(obj)
+        
+        return JSONEncoder.original_encode(self, obj, *args, **kwargs)
 
-    wrapped_default.default = JSONEncoder().default
+    wrapped_encoder.default = JSONEncoder().default
     # apply the patch
     JSONEncoder.original_default = JSONEncoder.default
-    JSONEncoder.default = wrapped_default
+    JSONEncoder.original_encode = JSONEncoder.encode
+    JSONEncoder.default = wrapped_encoder
+    JSONEncoder.encode = wrapped_encoder
 
 def fix_it(): pass # to support the old interface 
\ No newline at end of file
